@@ -1,20 +1,7 @@
 /*
- *   Copyright (C) 2014 Ivan Cukic <ivan.cukic(at)kde.org>
+ *   SPDX-FileCopyrightText: 2014 Ivan Cukic <ivan.cukic(at)kde.org>
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License version 2,
- *   or (at your option) any later version, as published by the Free
- *   Software Foundation
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *   SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef PLUGINS_SQLITE_DATABASE_UTILS_H
@@ -55,7 +42,7 @@ namespace Utils {
 
     enum ErrorHandling {
         IgnoreError,
-        FailOnError
+        FailOnError,
     };
 
     inline bool exec(Common::Database &database, ErrorHandling eh, QSqlQuery &query)
